@@ -1,11 +1,11 @@
 #' @title PATHMOX-PLS: Extended Segmentation Trees in 
-#' Partial Least Squares Path Modeling 
+#' Partial Least Squares Structutal Equation Modeling (PLS-SEM)
 #' 
 #' @description
 #' The function \code{pathmox.pls} calculates a binary segmentation tree in 
-#' the context PLS-PM  following the PATHMOX algorithm.
+#' the context PLS-SEM  following the PATHMOX algorithm.
 #' The procedure can be resumed in the following way. It starts with the 
-#' estimation of the global PLS Path Model at the root node. Then, using 
+#' estimation of the global PLS-SEM Model at the root node. Then, using 
 #' the segmentation variables, all possible binary splits of data are produced, 
 #' and for each partition local models are calculated. Among all the splits, 
 #' the best one is selected by means of the F-test comparing the inner models. 
@@ -22,12 +22,19 @@
 #' are proposed to overcome the parametric hypothesis of the F-test.
 #' 
 #' @details
-#' The argument \code{xpls} is object of class \code{"plspm"} returned by \code{\link{plspm}}.
+#' 
+#' The argument \code{x} must be a data frame containing the manifest variables of the 
+#' PLS-SEM model
+#' 
+#' The argument \code{inner} is a matrix of zeros and ones that indicates
+#' the structural relationships between latent variables. \code{inner} 
+#' must be a lower triangular matrix; it contains a 1 when column \code{j}
+#' affects row \code{i}, 0 otherwise. \cr
 #'
 #' The argument \code{SVAR} must be a data frame containing segmentation
 #' variables as factors. The number of rows in
 #' \code{SVAR} must be the same as the number of rows in the data used in
-#' \code{pls}. 
+#' \code{x}. 
 #'  
 #' The argument \code{signif} represent the p-value level takes as reference  
 #' to stop the tree partitions. 
@@ -46,11 +53,30 @@
 #' partition. If the candidate split produces a partition where the number of individuals is less  
 #' then \code{n.node}, the partition is not considered.
 #'
-#' When the object \code{pls} does not contain a data matrix (i.e.
-#' \code{pls$data=NULL}), the user must provide the data matrix or data frame in
-#' \code{X}.
-#' 
-#' @param xpls An object of class \code{"plspm"} returned by \code{\link{plspm}}.
+#'
+#' @param x matrix or data frame containing the manifest variables.
+#' @param inner A square (lower triangular) boolean matrix representing 
+#' the inner model (i.e. the path relationships between latent variables).
+#' @param outer list of vectors with column indices or column names
+#' from \code{x} indicating the sets of manifest variables forming 
+#' each block (i.e. which manifest variables correspond to each block).
+#' @param scaling optional argument for runing the non-metric approach; 
+#' it is a list of string vectors indicating the type of 
+#' measurement scale for each manifest variable specified in \code{outer}.
+#' \code{scaling} must be specified when working with non-metric variables.
+#' Possible values: \code{"num"} (linear transformation, 
+#' suitable for numerical variables), \code{"raw"} (no transformation), 
+#' \code{"nom"} (non-monotonic transformation, suitable for nominal variables), 
+#' and \code{"ord"} (monotonic transformation, suitable for ordinal variables).
+#' @param mode character vector indicating the type of measurement for each
+#' block. Possible values are: \code{"A", "B", "newA", "PLScore", "PLScow"}. 
+#' The length of \code{mode} must be equal to the length of \code{outer}.
+#' @param scheme string indicating the type of inner weighting
+#' scheme. Possible values are \code{"centroid"}, \code{"factorial"}, or
+#' \code{"path"}.
+#' @param scaled whether manifest variables should be standardized. 
+#' Only used when \code{scaling = NULL}. By the default (\code{TRUE}, data is 
+#' scaled to standardized values (mean=0 and variance=1). 
 #' @param SVAR A data frame of factors contaning the segmentation variables.
 #' @param signif A numeric value indicating the significance threshold of the
 #' F-statistic. Must be a decimal number between 0 and 1.
@@ -83,26 +109,19 @@
 #' @return \item{Fc.r}{A list of data frames containing the results of the F-coefficients test 
 #' for each node partition}
 #' @return \item{model}{Informations about the internal paramenters} 
+#' @return \item{hybrid}{a hybird categorical factor defined according to the final segments idenfied by pathmox} 
 #' 
 #' @author Giuseppe Lamberti
 #' 
+#' @references Lamberti, G. et al. (2017) \emph{The Pathmox approach for PLS path modeling: 
+#' Discovering which constructs differentiate segments}.Applied Stochastic Models in Business and Industry; 
+#' doi: 10.1002/asmb.2270; 
+#' 
 #' @references Lamberti, G. et al. (2016) \emph{The Pathmox approach for PLS path modeling segmentation}. 
 #' Applied Stochastic Models in Business and Industry; doi: 10.1002/asmb.2168; 
-#'
-#' @references Aluja, T., Lamberti, G., Sanchez, G. (2013). Extending the PATHMOX approach 
-#' to detect which constructs differentiate segments. In   H., Abdi,  W. W., Chin,  V., Esposito Vinzi, 
-#' G., Russolillo,  and   L., Trinchera (Eds.), Book title: New Perspectives in Partial Least 
-#' Squares and Related Methods (pp.269-280). Springer.
 #'               
 #' @references Lamberti, G. (2014) \emph{Modeling with Heterogeneity.} PhD Dissertation.
 #'
-#' @references Sanchez, G. (2009) \emph{PATHMOX Approach: Segmentation Trees in
-#' Partial Least Squares Path Modeling.} PhD Dissertation. 
-#' 
-#' @references Tenenhaus M., Esposito Vinzi V., Chatelin Y.M., and Lauro C.
-#' (2005) PLS path modeling. \emph{Computational Statistics & Data Analysis},
-#' \bold{48}, pp. 159-205.
-#'
 #' @export
 #' @examples
 #'
@@ -127,8 +146,6 @@
 #'  outer.fib  = list(1:8,9:11,12:16,17:20,21:24)
 #'  modes.fib  = rep("A", 5)
 #'  
-#'  # apply plspm
-#'  pls.fib = plspm(data.fib, inner.fib, outer.fib, modes.fib)
 #'                  
 #'  # re-ordering those segmentation variables with ordinal scale 
 #'   seg.fib= fibtele[,2:11]
@@ -142,7 +159,7 @@
 #'	    levels=c("<6.5note","6.5-7note","7-7.5note",">7.5note"), ordered=T)
 #'
 #'  # Pathmox Analysis
-#'  fib.pathmox=pls.pathmox(pls.fib,seg.fib,signif=0.05,
+#'  fib.pathmox=pls.pathmox(data.fib, inner.fib, outer.fib, modes.fib,SVAR=seg.fib,signif=0.05,
 #'					deep=2,size=0.2,n.node=20)
 #'  
 #'  }
@@ -166,8 +183,6 @@
 #'  outer.fib = list(1:8,9:11,12:16,17:20,21:24)
 #'  modes.fib = rep("A", 5)
 #'  
-#'  # apply plspm
-#'  pls.fib = plspm(data.fib, inner.fib, outer.fib, modes.fib)
 #'                  
 #'
 #'  # re-ordering those segmentation variables with ordinal scale 
@@ -176,95 +191,135 @@
 #'			levels=c("<18k","25k","35k","45k",">45k"), ordered=TRUE)
 #'
 #'  # Pathmox Analysis
-#'  fib.pathmox = pls.pathmox(pls.fib,seg.fib,signif=0.5,
-#'					deep=1,size=0.01,n.node=10)
+#'  fib.pathmox=pls.pathmox(data.fib, inner.fib, outer.fib, modes.fib,SVAR=seg.fib,signif=0.05,
+#'					deep=2,size=0.2,n.node=20)
 #'
 #'
-pls.pathmox = function(xpls,SVAR,signif,deep,method="lm",size,X = NULL,n.node=30,...)
+pls.pathmox = function(x,inner,outer,mode,scheme="path",scaling=NULL,scaled=TRUE,SVAR,signif,deep,method="lm",size,X = NULL,n.node=30,...)
 {
-    if (class(xpls) != "plspm") 
-        stop("Argument 'pls' must be an object of class 'plspm'")
-    
-    if (!is.null(X)) {
-        if (is.null(xpls$data)) {
-            if (!is.matrix(X) && !is.data.frame(X)) 
-                stop("Invalid object 'X'. Must be a numeric matrix or data frame.")
-            if (nrow(X) != nrow(xpls$latents)) 
-                stop("Argument 'pls' and 'X' are incompatible. Different number of rows.")
-            if (nrow(X) != nrow(SVAR)) 
-                stop("Arguments 'X' and 'SVAR' are incompatible. Different number of rows")
-        }
+
+    if (!is.null(x)) {
+      if (!is.matrix(x) && !is.data.frame(x)) 
+        stop("Invalid object 'X'. Must be a numeric matrix or data frame.")
+      if (nrow(x) != nrow(SVAR)) 
+        stop("Arguments 'X' and 'SVAR' are incompatible. Different number of rows")
     }
     else {
-        if (is.null(xpls$data)) {
-            stop("Argument 'X' is missing. No dataset available.")
-        }
-        else {
-            if (nrow(xpls$data) != nrow(SVAR)) 
-                stop("Arguments 'pls' and 'SVAR' are incompatible. Different number of rows")
-        }
+      if (is.null(x)) {
+        stop("Argument 'X' is missing. No dataset available.")
+      }
+      else {
+        if (nrow(x) != nrow(SVAR)) 
+          stop("Arguments 'pls' and 'SVAR' are incompatible. Different number of rows")
+      }
     }
     if (!is.data.frame(SVAR)) 
-        stop("Argument 'SVAR' must be a data frame containing factors")
+      stop("Argument 'SVAR' must be a data frame containing factors")
     for (j in 1:ncol(SVAR)) if (!is.factor(SVAR[, j])) 
-        stop("One or more columns in 'SVAR' are not factors")
-	
-	x		=	xpls$data
-	if (any(is.na(x)))
-	{
-        warning("Data contains NA: missing values are imputed by the Chained Equations method")
-		x=as.matrix(complete(mice(x,m=1,seed=30,printFlag=FALSE)))
+      stop("One or more columns in 'SVAR' are not factors")
+    
+    if (any(is.na(x)))
+    {
+      stop("Data contains NA: please provide a complete data-set")
     }
     if (!is.data.frame(SVAR))
     {
-        stop("Argument 'SVAR' must be a data frame containing factors")
+      stop("Argument 'SVAR' must be a data frame containing factors")
     }
     if (any(is.na(SVAR)))
     {
-        warning("data factors contains NA: missing values are imputed by the Chained Equations method")
-		SVAR=complete(mice(SVAR,m=1,seed=30,printFlag=FALSE))
+      stop("data factors contains NA: please provide a complete data factors")
     }             
     if (mode(signif) != "numeric" || length(signif) != 1 || signif <= 
         0 || signif >= 1) {
-        warning("NOTICE: Invalid argument 'signif'. Default value 0.05 was used", 
-            "\n")
-        signif <- 0.05
+      warning("NOTICE: Invalid argument 'signif'. Default value 0.05 was used", 
+              "\n")
+      signif <- 0.05
     }
-	if (mode(method) != "character" || method != "lm" && method != "lad" ){
-        warning("NOTICE: Invalid argument 'method'. Default method lm was used", 
-            "\n")
-        method <- "lm"  
+    if (mode(method) != "character" || method != "lm" && method != "lad" ){
+      warning("NOTICE: Invalid argument 'method'. Default method lm was used", 
+              "\n")
+      method <- "lm"  
     }
     if (mode(size) != "numeric" || length(size) != 1 || size <= 
         0) {
-        warning("NOTICE: Invalid argument 'size'. Default value 0.10 was used", 
-            "\n")
-        size <- 0.1
+      warning("NOTICE: Invalid argument 'size'. Default value 0.10 was used", 
+              "\n")
+      size <- 0.1
     }
     if (mode(deep) != "numeric" ||  deep < 
         1 || (deep%%1) != 0) {
-        warning("NOTICE: Invalid argument 'deep'. Default value 1 was used", 
-            "\n")
-        deep <- 1
+      warning("NOTICE: Invalid argument 'deep'. Default value 1 was used", 
+              "\n")
+      deep <- 1
     }
-	
-	info.mox.pls(signif,size,deep,SVAR)
+    
+    
+    if ( class(inner)[1] != "matrix")
+      stop("\n'inner' must be a matrix.")
+    
+    if (nrow(inner) == 1)
+      stop("\n'inner' must have more than one row")
+    
+    for (j in 1:ncol(inner)) 
+    {
+      for (i in 1:nrow(inner)) 
+      {
+        if (length(intersect(inner[i,j], c(1,0))) == 0)
+          stop("\nElements in 'inner' must be '1' or '0'")
+      }      
+    }
+    
+    if (!is.list(outer))
+      stop("\n'outer' must be a list.")
+    
+    # no duplicated elements within each block
+    mvs_duplicated = unlist(lapply(outer, duplicated))
+    if (any(mvs_duplicated))
+      stop("\nWrong 'outer'. Duplicated variables in a block are not allowed")
+    
+    # all elements in blocks of same mode
+    mvs_mode = unique(unlist(lapply(outer, mode)))
+    if (length(mvs_mode) > 1)
+      stop("\nAll elements in 'outer' must have the same mode")
+    
+    # check indices inside columns range of Data
+    if (mvs_mode == "numeric") {
+      blocks_in_data = match(unlist(outer), 1:ncol(x))
+      if (any(is.na(blocks_in_data)))
+        stop("\nIndices in 'outer' outside the number of columns in 'x'")
+    }
+    
+    # convert character blocks to numeric outer
+    if (mvs_mode == "character") {
+      data_names = colnames(x)
+      matched_names = match(unlist(outer), data_names)
+      if (any(is.na(matched_names))) {
+        bad_names = unlist(outer)[is.na(outer)]
+        stop(sprintf("\nUnrecognized name in 'outer': '%s'", bad_names))        
+      }
+      outer = lapply(outer, function(x, y) match(x, y), data_names)
+    }
+    
+    if (length(outer) != nrow(inner))
+      stop("\nNumber of rows in 'path_matrix' different from length of 'outer'.")	
 
-	model	= list(signif=signif,size=size,deep=deep,method=method,data=x,SVAR=SVAR)
+	info.mox.pls(signif,size,deep,SVAR)
 	
-	inner   	=	xpls$model$IDM
-	outer	  	=	xpls$model$blocks
-	mode		=	xpls$model$specs$modes
-	scaling 	= 	xpls$model$specs$scaling
-	scaled		=	xpls$model$specs$scaled
-	scheme		=  	xpls$model$specs$scheme	
+	model	= list(signif=signif,size=size,deep=deep,method=method,data=x,SVAR=SVAR,
+	             inner=inner,outer=outer,mode=mode,scheme=scheme,scaling=scaling, scaled=scaled)
 	
+	min.ind.node = percent.node(x,size)
+	
+	hybrid = NULL
+	
+
 	min.ind.node = percent.node(x,size)
 	
 	#init: create the root
 	id=0
 	t = new ("tree",id=id)
-	dim_row = xpls$model$gens$obs
+	dim_row = dim(model$data)[1]
 	elements = seq(1:dim_row)
 	id = id+1
 	root = new("node",id=id,elements=elements,father=0,childs=0)
@@ -341,6 +396,8 @@ pls.pathmox = function(xpls,SVAR,signif,deep,method="lm",size,X = NULL,n.node=30
 		Fg.r = fglobal.tree.pls(t)
 		Fb.r = fblock.tree.pls(t)
 		Fc.r = fcoef.tree.pls(t)
+		for( i in 2: length(terminal))  
+		  hybrid = c(hybrid, rep( i-1, length(terminal[[i]])))
 		res = list(MOX=MOX,
 				root=root,
 				terminal=terminal,
@@ -349,7 +406,8 @@ pls.pathmox = function(xpls,SVAR,signif,deep,method="lm",size,X = NULL,n.node=30
 				Fg.r=Fg.r,
 				Fb.r=Fb.r,
 				Fc.r=Fc.r,
-				model=model)
+				model=model,
+				hybrid = hybrid)
 	class(res) = "xtree.pls"
 }
  res
